@@ -23,14 +23,14 @@ cat << EOF > App_O_cross.txt
 148	3
 158	13
 EOF
-info=`gmt grdinfo -M -Cn App_O_geoid.nc`
-x0=`echo $info | cut -f11 -d ' '`
-y0=`echo $info | cut -f12 -d ' '`
-x1=`echo $info | cut -f13 -d ' '`
-y1=`echo $info | cut -f14 -d ' '`
+info=$(gmt grdinfo -M -Cn App_O_geoid.nc)
+x0=$(echo $info | cut -f11 -d ' ')
+y0=$(echo $info | cut -f12 -d ' ')
+x1=$(echo $info | cut -f13 -d ' ')
+y1=$(echo $info | cut -f14 -d ' ')
 gmt project -C$x0/$y0 -E$x1/$y1 -G10 -Q > tt.d
-dist=`gmt convert tt.d --FORMAT_FLOAT_OUT=%.0lf -El -o2`
-R=`gmt info -I1 tt.d`
+dist=$(gmt convert tt.d --FORMAT_FLOAT_OUT=%.0lf -El -o2)
+R=$(gmt info -I1 tt.d)
 echo "# Geoid Extrema Separation is $dist km" > App_O_transect.txt
 gmt grdtrack tt.d -GApp_O_geoid.nc | gmt grdtrack -GGMT_App_O.nc >> App_O_transect.txt
 rm -f tt.d gmt.history
