@@ -1,9 +1,9 @@
-"/ISO-8859-3_Encoding [\n\
+"/ISO-8859-1_Encoding [\n\
 /.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef\n\
 /.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef\n\
 /.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef\n\
 /.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef\n\
-/space		/exclam		/quotedbl	/numbersign	/dollar		/percent	/ampersand	/quoteright\n\
+/space		/exclam		/quotedbl	/numbersign	/dollar		/percent	/ampersand	/quotesingle\n\
 /parenleft	/parenright	/asterisk	/plus		/comma		/hyphen		/period		/slash\n\
 /zero		/one		/two		/three		/four		/five		/six		/seven\n\
 /eight		/nine		/colon		/semicolon	/less		/equal		/greater	/question\n\
@@ -11,24 +11,24 @@
 /H		/I		/J		/K		/L		/M		/N		/O\n\
 /P		/Q		/R		/S		/T		/U		/V		/W\n\
 /X		/Y		/Z		/bracketleft	/backslash	/bracketright	/asciicircum	/underscore\n\
-/quoteleft	/a		/b		/c		/d		/e		/f		/g\n\
+/grave		/a		/b		/c		/d		/e		/f		/g\n\
 /h		/i		/j		/k		/l		/m		/n		/o\n\
 /p		/q		/r		/s		/t		/u		/v		/w\n\
-/x		/y		/z		/braceleft	/bar		/braceright	/tilde		/.notdef\n\
+/x		/y		/z		/braceleft	/bar		/braceright	/asciitilde	/.notdef\n\
 /.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef\n\
 /.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef\n\
 /.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef\n\
 /.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef\n\
-/space		/Hstroke	/breve		/sterling	/currency	/yen		/Hcircumflex	/section\n\
-/dieresis	/Idot		/Scedilla	/Gbreve		/Jcircumflex	/hyphen		/registered	/Zdot\n\
-/degree		/hstroke	/twosuperior	/threesuperior	/acute		/mu		/hcircumflex	/bullet\n\
-/cedilla	/dotlessi	/scedilla	/gbreve		/jcircumflex	/onehalf	/threequarters	/zdot\n\
-/Agrave		/Aacute		/Acircumflex	/Atilde		/Adieresis	/Cdot		/Ccircumflex	/Ccedilla\n\
+/space		/exclamdown	/cent		/sterling	/currency	/yen		/brokenbar	/section\n\
+/dieresis	/copyright	/ordfeminine	/guillemotleft	/logicalnot	/hyphen		/registered	/macron\n\
+/degree		/plusminus	/twosuperior	/threesuperior	/acute		/mu		/paragraph	/periodcentered\n\
+/cedilla	/onesuperior	/ordmasculine	/guillemotright	/onequarter	/onehalf	/threequarters	/questiondown\n\
+/Agrave		/Aacute		/Acircumflex	/Atilde		/Adieresis	/Aring		/AE		/Ccedilla\n\
 /Egrave		/Eacute		/Ecircumflex	/Edieresis	/Igrave		/Iacute		/Icircumflex	/Idieresis\n\
-/Eth		/Ntilde		/Ograve		/Oacute		/Ocircumflex	/Gdot		/Odieresis	/multiply\n\
-/Gcircumflex	/Ugrave		/Uacute		/Ucircumflex	/Udieresis	/Ubreve		/Scircumflex	/germandbls\n\
-/agrave		/aacute		/acircumflex	/atilde		/adieresis	/cdot		/ccircumflex	/ccedilla\n\
+/Eth		/Ntilde		/Ograve		/Oacute		/Ocircumflex	/Otilde		/Odieresis	/multiply\n\
+/Oslash		/Ugrave		/Uacute		/Ucircumflex	/Udieresis	/Yacute		/Thorn		/germandbls\n\
+/agrave		/aacute		/acircumflex	/atilde		/adieresis	/aring		/ae		/ccedilla\n\
 /egrave		/eacute		/ecircumflex	/edieresis	/igrave		/iacute		/icircumflex	/idieresis\n\
-/eth		/ntilde		/ograve		/oacute		/ocircumflex	/gdot		/odieresis	/divide\n\
-/gcircumflex	/ugrave		/uacute		/ucircumflex	/udieresis	/ubreve		/scircumflex	/dotaccent\n\
+/eth		/ntilde		/ograve		/oacute		/ocircumflex	/otilde		/odieresis	/divide\n\
+/oslash		/ugrave		/uacute		/ucircumflex	/udieresis	/yacute		/thorn		/ydieresis\n\
 ] def\n",
