@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *	Copyright (c) 1991-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -73,8 +73,10 @@
 #define GMT_CONV12_LIMIT 1.0e-12	/* Tight limit for gaps/overlaps in CPT z-values */
 #define GMT_CONV8_LIMIT	 1.0e-8		/* Fairly tight convergence limit or "close to zero" limit */
 #define GMT_CONV6_LIMIT	 1.0e-6		/* 1 ppm */
+#define GMT_CONV5_LIMIT	 1.0e-5		/* 10 ppm */
 #define GMT_CONV4_LIMIT	 1.0e-4		/* Less tight convergence limit or "close to zero" limit */
 
+#define GMT_ASCII_ES	27	/* ASCII code for escape (used to prevent +? strings in plain text from being seen as modifiers) */
 #define GMT_ASCII_GS	29	/* ASCII code for group separator (temporarily replacing tabs) */
 #define GMT_ASCII_RS	30	/* ASCII code for record separator (temporarily replacing spaces in filenames) */
 #define GMT_ASCII_US	31	/* ASCII code for unit separator (temporarily replacing spaces in quoted text) */
@@ -86,7 +88,7 @@
 #define GMT_TOP_MODULE	1	/* func_level of top-level module being called */
 
 #define GMT_PAPER_DIM		32767	/* Upper limit on PostScript paper size under modern mode, in points (~11.6 meters) */
-#define GMT_PAPER_MARGIN	5	/* Default paper margin under modern mode, in inches (~1 meter) */
+#define GMT_PAPER_MARGIN	5	/* Default paper margin under modern mode, in inches (12.7 centimeter) */
 
 /*! whether to ignore/read/write history file gmt.history */
 enum GMT_enum_history {
@@ -121,6 +123,7 @@ enum GMT_enum_length {
 	GMT_LEN256      = 256U,         /* Max size of some text items */
 	GMT_LEN512      = 512U,         /* Max size of other text items */
 	GMT_LEN1024     = 1024U,        /* For file names (antecipating web fnames) */
+	GMT_MAX_RANGES  = 64U,          /* Limit on number of row ranges given in -q */
 	GMT_MAX_COLUMNS = 4096U,        /* Limit on number of columns in data tables (not grids) */
 	GMT_BUFSIZ      = 4096U,        /* Size of char record for i/o */
 	GMT_MSGSIZ      = 16384U,       /* Size of char record for messages and report */
@@ -150,11 +153,18 @@ enum GMT_swap_direction {
 	k_swap_in,
 	k_swap_out};
 
+/*! Scripting languages */
+enum GMT_enum_script {GMT_BASH_MODE = 0,	/* Write Bash script */
+	GMT_CSH_MODE,			/* Write C-shell script */
+	GMT_DOS_MODE};			/* Write DOS script */
+
+#define GMT_VERBOSE_CODES	"q ewticd"	/* List of valid codes to -V (the blank is for NOTICE which is not user selectable */
 #define GMT_DIM_UNITS	"cip"		/* Plot dimensions in cm, inch, or point */
 #define GMT_LEN_UNITS2	"efkMnu"	/* Distances in meter, foot, survey foot, km, Mile, nautical mile */
 #define GMT_LEN_UNITS	"dmsefkMnu"	/* Distances in arc-{degree,minute,second} or meter, foot, km, Mile, nautical mile, survey foot */
 #define GMT_TIME_UNITS	"yowdhms"	/* Time increments in year, month, week, day, hour, min, sec */
 #define GMT_TIME_VAR_UNITS	"yo"	/* Variable time increments in year or month*/
+#define GMT_WESN_UNITS	"WESN"		/* Sign-letters for geographic coordinates */
 #define GMT_DIM_UNITS_DISPLAY	"c|i|p"			/* Same, used to display as options */
 #define GMT_LEN_UNITS_DISPLAY	"d|m|s|e|f|k|M|n|u"	/* Same, used to display as options */
 #define GMT_LEN_UNITS2_DISPLAY	"e|f|k|M|n|u"		/* Same, used to display as options */
@@ -208,18 +218,14 @@ enum GMT_swap_direction {
 #define GMT_IMAGE_LAYOUT	"TRBa"	/* Standard GMT scanline band-interleaved image */
 
 #define GMT_CPT_CONTINUOUS	8	/* Final CPT should be continuous */
-#define GMT_CPT_TEMPORARY	16	/* CPT was built from list of colors, e.g., red,green,255,blue,... */
+#define GMT_CPT_TEMPORARY	1024	/* CPT was built from list of colors, e.g., red,green,255,blue,... */
 #define GMT_CPT_C_REVERSE	1	/* Reverse CPT colors */
 #define GMT_CPT_Z_REVERSE	2	/* Reverse CPT z-values */
 
-/* Default CPTs are initialized in gmt_init.c; see end of gmtinit_new_GMT_ctrl */ 
-#define GMT_DEFAULT_CPT		0	/* Default index into GMT->init.cpt[] array */
-#define GMT_N_CPT		3		/* Number of default CPT types (see GMT->init.cpt in gmt_init.c) */
+/* Default CPT if nothing specified or overruled by remote dataset preferences */
 #define GMT_DEFAULT_CPT_NAME	"turbo"
-#define GMT_DEM_CPT_NAME		"geo"
-#define GMT_SRTM_CPT_NAME		"srtm"
 
-#define GMT_IS_ROMAN_LCASE	1	/* For converting arabic numerals to Roman */
+#define GMT_IS_ROMAN_LCASE	1	/* For converting Arabic numerals to Roman */
 #define GMT_IS_ROMAN_UCASE	2
 
 /* Settings for the MAP_FRAME_TYPE = graph */
@@ -230,6 +236,12 @@ enum GMT_swap_direction {
 #define GMT_SUBPLOT_ACTIVE	1
 #define GMT_PANEL_NOTSET	2
 
+/* Fraction of increment to force outward region expansion */
+#define GMT_REGION_INCFACTOR 0.25
+
+/* Allowable refpoint codes */
+#define GMT_REFPOINT_CODES "gjJnx"
+
 /*! Codes for grdtrack */
 enum GMT_enum_tracklayout {
 	GMT_LEFT_RIGHT = 1,
@@ -250,6 +262,24 @@ enum GMT_enum_inside {
 	GMT_ONEDGE,
 	GMT_INSIDE};
 
+/*! Return codes from gmt_polygon_orientation */
+enum GMT_enum_polorient {
+	GMT_POL_IS_CCW = 0,
+	GMT_POL_IS_CW  = 1};
+
+/*! Codes for -q selections */
+enum GMT_enum_skiprows {
+	GMT_RANGE_ROW_IN   = 1,
+	GMT_RANGE_DATA_IN  = 2,
+	GMT_RANGE_ROW_OUT  = 3,
+	GMT_RANGE_DATA_OUT = 4};
+
+/*! Return codes from parsing region modifiers +r,+R,+e */
+enum GMT_enum_region {
+	GMT_REGION_ADD = 1,
+	GMT_REGION_ROUND,
+	GMT_REGION_ROUND_EXTEND};
+
 /*! Return codes from gmt_get_refpoint */
 enum GMT_enum_refpoint {
 	GMT_REFPOINT_NOTSET = -1,	/* -D */
@@ -281,9 +311,14 @@ enum GMT_enum_download {
 
 /*! Various mode for auto-legend pens */
 enum GMT_enum_autolegend {
-	GMT_LEGEND_PEN_D  = 0, GMT_LEGEND_PEN_V  = 1,
+	GMT_LEGEND_PEN_D  = 0, GMT_LEGEND_PEN_V  = 1, GMT_LEGEND_PEN_P  = 2,
 	GMT_LEGEND_DRAW_D = 1, GMT_LEGEND_DRAW_V = 2};
 
+/*! Various mode for custom symbols */
+enum GMT_enum_customsymb {
+	GMT_CUSTOM_DEF  = 1,
+	GMT_CUSTOM_EPS  = 2};
+
 //#define GMT_LEGEND_DX1_MUL 1.0	/* Default offset from margin to center of symbol if given as '-' times max symbol size */
 //#define GMT_LEGEND_DX2_MUL 2.0	/* Default offset from margin to start of label if given as '-' times max symbol size */
 #define GMT_LEGEND_DX1_MUL 0.5	/* Default offset from margin to center of symbol if given as '-' times max symbol size */
@@ -328,7 +363,8 @@ enum GMT_enum_runmode {
 enum GMT_enum_workflowmode {
 	GMT_USE_WORKFLOW = 0, 	/* Default is to use current workflow if initiated and ignore if otherwise */
 	GMT_BEGIN_WORKFLOW = 1,	/* Initiate a new workflow via gmt begin */
-	GMT_END_WORKFLOW = 2};  /* Terminate current workflow via gmt begin */
+	GMT_END_WORKFLOW = 2,  /* Terminate current workflow via gmt begin */
+	GMT_CLEAN_WORKFLOW = 4};  /* If given with BEGIN we ignore any gmt.conf files */
 
 /*! Selections for pen/fill color replacements in custom symbol macros */
 enum GMT_enum_colorswap {
@@ -345,14 +381,25 @@ enum GMT_enum_spline {
 	GMT_SPLINE_LINEAR = 0, /* Linear spline */
 	GMT_SPLINE_AKIMA,      /* Akima spline */
 	GMT_SPLINE_CUBIC,      /* Cubic spline */
+	GMT_SPLINE_SMOOTH,     /* Smooth cubic spline */
 	GMT_SPLINE_NN,         /* Nearest neighbor */
 	GMT_SPLINE_NONE};      /* No spline set */
 
+/*! Various 1-D interpolation derivatives */
+enum GMT_enum_derivative {
+	GMT_SPLINE_SLOPE = 10,		 /* Spline 1st derivative*/
+	GMT_SPLINE_CURVATURE = 20};   /* Spline 2nd derivative */
+
 enum GMT_enum_extrap {
 	GMT_EXTRAPOLATE_NONE = 0,   /* No extrapolation; set to NaN outside bounds */
 	GMT_EXTRAPOLATE_SPLINE,     /* Let spline extrapolate beyond bounds */
 	GMT_EXTRAPOLATE_CONSTANT};  /* Set extrapolation beyond bound to specifiec constant */
 
+enum GMT_enum_cross {
+	GMT_CROSS_NORMAL = 0,	/* Regular grid cross */
+	GMT_CROSS_ASYMM,    	/* Asymmetrical tick away from Equator/Greenwich */
+	GMT_CROSS_SYMM}; 	/* Symmetric grid ticks */
+
 /*! Timer reporting modes */
 enum GMT_enum_tictoc {
 	GMT_NO_TIMER = 0,	/* No timer reported */
@@ -406,7 +453,7 @@ enum GMT_enum_anchors {	/* Various anchor strings */
 enum GMT_enum_scales {	/* Various scale issues */
 	GMT_SCALE_MAP = 1,
 	GMT_SCALE_FREE = 2};
-		
+
 enum GMT_enum_radius {	/* Various "average" radii for an ellipsoid with axes a,a,b */
 	GMT_RADIUS_MEAN = 0,	/* Mean radius IUGG R_1 = (2*a+b)/3 = a (1 - f/3) */
 	GMT_RADIUS_AUTHALIC,	/* Authalic radius 4*pi*r^2 = surface area of ellipsoid, R_2 = sqrt (0.5a^2 + 0.5b^2 (tanh^-1 e)/e) */
@@ -477,6 +524,8 @@ enum GMT_enum_sph {GMT_DIST_M = 10,	/* 2-D lon, lat data, convert distance to me
 	GMT_DIST_DEG = 20,	/* 2-D lon, lat data, convert distance to spherical degree */
 	GMT_DIST_COS = 30};	/* 2-D lon, lat data, convert distance to cos of spherical degree */
 
+enum enum_item {MOVIE_ITEM_IS_LABEL = 0,	/* Item is a frame counter or time label in movie */
+	MOVIE_ITEM_IS_PROG_INDICATOR};			/* Item is a progress indicator symbol in movie */
 
 /* Help us with big and little endianness */
 #ifdef WORDS_BIGENDIAN
@@ -493,15 +542,10 @@ enum GMT_enum_curl {GMT_REGULAR_FILE = 0,	/* Regular file the may or may not exi
 	GMT_DATA_FILE  = 2,	/* Official GMT data file destined for the user's user dir */
 	GMT_URL_FILE   = 3,	/* Data given by an URL destined for the cache */
 	GMT_URL_QUERY  = 4,	/* Data given by an URL CGI command destined for the cache */
-	GMT_CACHE_DIR  = 0,	/* Use the cache directory */
-	GMT_DATA_DIR   = 1,	/* Use the data directory */
-	GMT_LOCAL_DIR  = 2};	/* Use the local (current) directory */
-
-#define GMT_DATA_PREFIX "earth_relief_"				/* Special prefix for global relief data sets */
-#define GMT_SRTM_PREFIX "srtm_relief_"				/* Special prefix for srtm relief data sets when ocean is not requested */
-#define GMT_SRTM_EXTENSION_REMOTE  "jp2"			/* Tile extension of JPEG2000 files to be downloaded */
-#define GMT_SRTM_EXTENSION_REMOTE_LEN  4U			/* Length of JPEG2000 file extension (+1) */
-#define GMT_SRTM_EXTENSION_LOCAL "nc"				/* Tile extension of nc short int files to be saved */
-#define GMT_SRTM_EXTENSION_LOCAL_LEN 2U				/* Length of  nc short int file extension */
+	GMT_AUTO_DIR   = 0,	/* Use the directory given per internal rules */
+	GMT_CACHE_DIR  = 1,	/* Use the cache directory */
+	GMT_DATA_DIR   = 2,	/* Use the data directory */
+	GMT_LOCAL_DIR  = 3,	/* Use the local (current) directory */
+	GMT_REMOTE_DIR = 4}; /* File is on the remote server */
 
 #endif  /* GMT_CONSTANTS_H */
