@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *	Copyright (c) 1991-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
  *
  * Public functions (2):
  *
- *	gmt_is_gdal_grid : Determine if a grid is GDAL readable
+ *	gmtlib_is_gdal_grid : Determine if a grid is GDAL readable
  *	gmt_gdalread     : Read a GDAL grid
  */
 
@@ -33,12 +33,12 @@
 
 GMT_LOCAL GDALDatasetH gdal_open (struct GMT_CTRL *GMT, char *gdal_filename) {
 	char *file = NULL, path[PATH_MAX] = {""};
-	if (gmtlib_check_url_name (gdal_filename))	/* A vis*** URL, pass to GDAL as is */
+	if (gmtlib_found_url_for_gdal (gdal_filename))	/* A vis*** URL, pass to GDAL as is */
 		strncpy (path, gdal_filename, PATH_MAX-1);
 	else if (strchr(gdal_filename, ':'))		/* Assume it is a SUBDATASET */
 		strncpy (path, gdal_filename, PATH_MAX-1);
 	else if ((file = gmt_getdatapath (GMT, gdal_filename, path, R_OK)) == NULL) {	/* Local file not found */
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Unable to find %s.\n", gdal_filename);
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Unable to find %s.\n", gdal_filename);
 		return (NULL);
 	}
 	return (GDALOpen (path, GA_ReadOnly));
@@ -209,7 +209,7 @@ GMT_LOCAL void ComputeRasterMinMax(struct GMT_CTRL *GMT, unsigned char *tmp, GDA
 			}
 			break;
 		default:
-			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "gdalread: Unsupported data type\n");
+			GMT_Report (GMT->parent, GMT_MSG_ERROR, "gdalread: Unsupported data type\n");
 			break;
 	}
 	adfMinMax[0] = z_min;
@@ -326,11 +326,13 @@ GMT_LOCAL int populate_metadata (struct GMT_CTRL *GMT, struct GMT_GDALREAD_OUT_C
 	/* ------------------------------------------------------------------------- */
 	hDataset = gdal_open (GMT, gdal_filename);
 	if (hDataset == NULL) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Unable to open %s.\n", gdal_filename);
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "Unable to open %s.\n", gdal_filename);
 		GDALDestroyDriverManager();
 		return (-1);
 	}
 
+	gmt_M_tic (GMT);
+
 	/* ------------------------------------------------------------------------- */
 	/* Record the ProjectionRef */
 	/* ------------------------------------------------------------------------- */
@@ -385,7 +387,7 @@ GMT_LOCAL int populate_metadata (struct GMT_CTRL *GMT, struct GMT_GDALREAD_OUT_C
 	}
 	else if (adfGeoTransform[1] != 1 && adfGeoTransform[5] != 1) {	/* Patch a possible GDAL bug. Raised after issue #1030 */
 		adfGeoTransform[1] = adfGeoTransform[5] = 1;
-		GMT_Report(GMT->parent, GMT_MSG_VERBOSE, "GDAL seamed to have returned garbage in adfGeoTransform. Arbitrarily setting inc = 1.\n");
+		GMT_Report(GMT->parent, GMT_MSG_WARNING, "GDAL seamed to have returned garbage in adfGeoTransform. Arbitrarily setting inc = 1.\n");
 	}
 
 	/* ------------------------------------------------------------------------- */
@@ -404,11 +406,11 @@ GMT_LOCAL int populate_metadata (struct GMT_CTRL *GMT, struct GMT_GDALREAD_OUT_C
 		int	anSrcWin[4];
 		anSrcWin[0] = anSrcWin[1] = anSrcWin[2] = anSrcWin[3] = 0;
 		if (adfGeoTransform[2] != 0.0 || adfGeoTransform[4] != 0.0) {
-			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "The -projwin option was used, but the geotransform is rotated."
+			GMT_Report (GMT->parent, GMT_MSG_ERROR, "The -projwin option was used, but the geotransform is rotated."
 			                                         " This configuration is not supported.\n");
 			GDALClose(hDataset);
 			GDALDestroyDriverManager();
-			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Quitting with error\n");
+			GMT_Report (GMT->parent, GMT_MSG_ERROR, "Quitting with error\n");
 			return(-1);
 		}
 
@@ -420,9 +422,9 @@ GMT_LOCAL int populate_metadata (struct GMT_CTRL *GMT, struct GMT_GDALREAD_OUT_C
 		if (anSrcWin[0] < 0 || anSrcWin[1] < 0
 		    || anSrcWin[0] + anSrcWin[2] > GDALGetRasterXSize(hDataset)
 		    || anSrcWin[1] + anSrcWin[3] > GDALGetRasterYSize(hDataset)) {
-			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Computed -srcwin falls outside raster size of %dx%d.\n",
+			GMT_Report (GMT->parent, GMT_MSG_ERROR, "Computed -srcwin falls outside raster size of %dx%d.\n",
 			            GDALGetRasterXSize(hDataset), GDALGetRasterYSize(hDataset));
-			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Quitting with error\n");
+			GMT_Report (GMT->parent, GMT_MSG_ERROR, "Quitting with error\n");
 			return(-1);
 		}
 		Ctrl->RasterXsize = nXSize = anSrcWin[2];
@@ -493,7 +495,7 @@ GMT_LOCAL int populate_metadata (struct GMT_CTRL *GMT, struct GMT_GDALREAD_OUT_C
 		   Note, however, that first band colormap is captured anyway (if exists, off course) */
 
 		if (bSuccess == 0 && strstr(Ctrl->DriverShortName, "HDF5") != NULL) {	/* several methods for HDF5 driver are not implemented */
-			GMT_Report(GMT->parent, GMT_MSG_LONG_VERBOSE, "An HDF5 file. Trying to get scale_offset from string metadata.\n");
+			GMT_Report(GMT->parent, GMT_MSG_INFORMATION, "An HDF5 file. Trying to get scale_offset from string metadata.\n");
 			dfNoDataValue = GMT->session.d_NaN;
 			get_attrib_from_string(Ctrl, hBand, nBand, &dfNoDataValue);			/* Go get them from the metadata in strings. */
 			if (!isnan(dfNoDataValue)) got_noDataValue = true;
@@ -538,8 +540,18 @@ GMT_LOCAL int populate_metadata (struct GMT_CTRL *GMT, struct GMT_GDALREAD_OUT_C
 		Ctrl->ColorMap[j++] = -1;
 	}
 	else {
-		Ctrl->ColorMap = NULL;
-		Ctrl->nIndexedColors  = 0;
+		/* Before giving up, check if band is a 1-bit type */
+		const char *pszNBits = GDALGetMetadataItem(hBand, "NBITS", "IMAGE_STRUCTURE");
+		if (pszNBits && !strcmp(pszNBits, "1")) {
+			Ctrl->nIndexedColors = 2;
+			Ctrl->ColorMap = gmt_M_memory(GMT, NULL, Ctrl->nIndexedColors*4+1, int);
+			Ctrl->ColorMap[0] = Ctrl->ColorMap[1] = Ctrl->ColorMap[2] = 0;		Ctrl->ColorMap[3] = 1;
+			Ctrl->ColorMap[4] = Ctrl->ColorMap[5] = Ctrl->ColorMap[6] = 255;	Ctrl->ColorMap[7] = 1;
+		}
+		else {
+			Ctrl->ColorMap = NULL;
+			Ctrl->nIndexedColors  = 0;
+		}
 	}
 
 	/* ------------------------------------------------------------------------- */
@@ -624,11 +636,7 @@ GMT_LOCAL int populate_metadata (struct GMT_CTRL *GMT, struct GMT_GDALREAD_OUT_C
 	/* Fill in the rest of the GMT header values (If ...) */
 	if (raster_count > 0) {
 		if (z_min == 1e50) {		/* We don't know yet the dataset Min/Max */
-			/* If file is a "VRT/Virtual Raster" do NOT try to compute min/max and trust on XML info */
-			if (strcmp(Ctrl->DriverShortName, "VRT"))
-				GDALComputeRasterMinMax(hBand, false, adfMinMax);		/* NO VRT, scan file to compute min/max */
-			else
-				GDALComputeRasterMinMax(hBand, true, adfMinMax);		/* VRT, believe in metadata info */
+			GDALComputeRasterMinMax(hBand, true, adfMinMax);		/* Trust on metadata min/max */
 			Ctrl->hdr[4] = adfMinMax[0];
 			Ctrl->hdr[5] = adfMinMax[1];
 		}
@@ -641,12 +649,15 @@ GMT_LOCAL int populate_metadata (struct GMT_CTRL *GMT, struct GMT_GDALREAD_OUT_C
 		   example file to test it. The example mentioned in issue http://gmtrac.soest.hawaii.edu/issues/254
 		   (where all this (re)started) not only is bugged as does not carry the AREA_OR_POINT metadata.
 		   So we'll check for the "Area" keyword and if found we will respect it and set grid to pix reg */
-		if (!pixel_reg && GDALGetMetadataItem(hDataset, "AREA_OR_POINT", NULL) &&
+		if (gmtlib_file_is_jpeg2000_tile (GMT->parent, gdal_filename) != GMT_NOTSET && (Ctrl->RasterXsize % 2) == 0 && (Ctrl->RasterYsize % 2) == 0)
+			/* PW: Reading GMT server special JP2 tiles: even size implies pixel registration */
+			pixel_reg = true;
+		else if (!pixel_reg && GDALGetMetadataItem(hDataset, "AREA_OR_POINT", NULL) &&
 			!strcmp(GDALGetMetadataItem(hDataset, "AREA_OR_POINT", NULL), "Area"))
-			pixel_reg = 1;
+			pixel_reg = true;
 		else if (!pixel_reg && GDALGetMetadataItem(hDataset, "GDALMD_AREA_OR_POINT", NULL) &&
 			!strcmp(GDALGetMetadataItem(hDataset, "GDALMD_AREA_OR_POINT", NULL), "Area"))
-			pixel_reg = 1;
+			pixel_reg = true;
 
 		Ctrl->hdr[6] = pixel_reg;
 		Ctrl->hdr[7] = adfGeoTransform[1];
@@ -666,6 +677,8 @@ GMT_LOCAL int populate_metadata (struct GMT_CTRL *GMT, struct GMT_GDALREAD_OUT_C
 
 	GDALClose (hDataset);
 
+	gmt_M_toc (GMT, "In populate_metadata");
+
 	return (GMT_NOERROR);
 }
 
@@ -674,7 +687,7 @@ GMT_LOCAL int populate_metadata (struct GMT_CTRL *GMT, struct GMT_GDALREAD_OUT_C
  *----------------------------------------------------------|
  */
 
-int gmt_is_gdal_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
+int gmtlib_is_gdal_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 	GDALDatasetH hDataset;
 	GDALDriverH	hDriver;
 	struct GMT_GRID_HEADER_HIDDEN *HH = gmt_get_H_hidden (header);
@@ -687,7 +700,7 @@ int gmt_is_gdal_grid (struct GMT_CTRL *GMT, struct GMT_GRID_HEADER *header) {
 
 	if (hDataset == NULL)
 		return (GMT_GRDIO_BAD_VAL);
-	GMT_Report (GMT->parent, GMT_MSG_LONG_VERBOSE, "File %s reads with GDAL driver %s\n",
+	GMT_Report (GMT->parent, GMT_MSG_INFORMATION, "File %s reads with GDAL driver %s\n",
 	            HH->name, GDALGetDriverShortName(GDALGetDatasetDriver(hDataset)));
 	GDALClose (hDataset);
 	GDALDestroyDriverManager();
@@ -745,8 +758,8 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 	}
 	first_layer = (nReqBands) ? whichBands[0] : 1;		/* The one used to get data type and header info */
 
-	if (nReqBands && GMT->current.setting.verbose >= GMT_MSG_LONG_VERBOSE) {
-		GMT_Report (GMT->parent, GMT_MSG_LONG_VERBOSE, "Read band(s):");
+	if (nReqBands && GMT->current.setting.verbose >= GMT_MSG_INFORMATION) {
+		GMT_Report (GMT->parent, GMT_MSG_INFORMATION, "Read band(s):");
 		for (k = 0; k < nReqBands; k++)
 			GMT_Message (GMT->parent, GMT_TIME_NONE, "\t%d", whichBands[k]);
 		GMT_Message (GMT->parent, GMT_TIME_NONE, "\n");
@@ -773,7 +786,7 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 		prhs->O.mem_layout[0] = topdown  ? 'T' : 'B';
 		prhs->O.mem_layout[1] = rowmajor ? 'R' : 'C';
 		prhs->O.mem_layout[2] = do_BIP   ? 'P' : 'B';
-		prhs->O.mem_layout[3] = 'a';
+		prhs->O.mem_layout[3] = 'a';		/* If later we find image has 4 layers, this will become 'A' */
 	}
 
 	if (prhs->p.active) pad = prhs->p.pad;
@@ -783,7 +796,7 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 		double wesn[4];
 		got_R = true;
 		error += (GMT_Get_Values (GMT->parent, prhs->R.region, wesn, 4) < 4);
-		
+
 		if (!error) {
 			double dx = 0, dy = 0;
 			if (!prhs->registration.val) {	/* Subregion coords are grid-reg. Need to convert to pix-reg */
@@ -814,7 +827,7 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 	}
 
 	if (error) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "gmt_gdalread failed to extract a Sub-region\n");
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "gmt_gdalread failed to extract a Sub-region\n");
 		return (-1);
 	}
 
@@ -842,7 +855,7 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 		}
 		else {
 			Ctrl->ProjRefWKT = NULL;
-			GMT_Report (GMT->parent, GMT_MSG_VERBOSE, "gmt_gdalread failed to convert the proj4 string\n%s\n to WKT\n",
+			GMT_Report (GMT->parent, GMT_MSG_WARNING, "gmt_gdalread failed to convert the proj4 string\n%s\n to WKT\n",
 					Ctrl->ProjRefPROJ4);
 		}
 
@@ -875,7 +888,7 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 	hDataset = gdal_open (GMT, gdal_filename);
 
 	if (hDataset == NULL) {
-		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "GDALOpen failed %s\n", CPLGetLastErrorMsg());
+		GMT_Report (GMT->parent, GMT_MSG_ERROR, "GDALOpen failed %s\n", CPLGetLastErrorMsg());
 		gmt_M_free (GMT, whichBands);
 		return (-1);
 	}
@@ -902,7 +915,7 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 		GDALGetGeoTransform(hDataset, adfGeoTransform);
 
 		if (adfGeoTransform[2] != 0.0 || adfGeoTransform[4] != 0.0) {
-			GMT_Report (GMT->parent, GMT_MSG_NORMAL,
+			GMT_Report (GMT->parent, GMT_MSG_ERROR,
 			            "The -projwin option was used, but the geotransform is rotated. This configuration is not supported.\n");
 			GDALClose(hDataset);
 			GDALDestroyDriverManager();
@@ -930,7 +943,7 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 		if (anSrcWin[0] < 0 || anSrcWin[1] < 0
 			|| anSrcWin[0] + anSrcWin[2] > GDALGetRasterXSize(hDataset)
 			|| anSrcWin[1] + anSrcWin[3] > GDALGetRasterYSize(hDataset)) {
-			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Computed -srcwin falls outside raster size of %dx%d.\n",
+			GMT_Report (GMT->parent, GMT_MSG_ERROR, "Computed -srcwin falls outside raster size of %dx%d.\n",
 			            GDALGetRasterXSize(hDataset), GDALGetRasterYSize(hDataset));
 			GDALDestroyDriverManager();
 			gmt_M_free (GMT, whichBands);
@@ -961,6 +974,8 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 
 	nBands = GDALGetRasterCount(hDataset);
 
+	if (nBands == 4) prhs->O.mem_layout[3] = 'A';
+
 	if (nReqBands) nBands = MIN(nBands,nReqBands);	/* If a band selection was made */
 
 	n_alloc = ((size_t)nBands) * ((size_t)nBufXSize + pad_w + pad_e) * ((size_t)nBufYSize + pad_s + pad_n);
@@ -983,6 +998,8 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 		case GDT_Int16:
 			if (prhs->f_ptr.active)		/* Use the previously allocated float pointer */
 				Ctrl->Float.data = prhs->f_ptr.grd;
+			else if (prhs->c_ptr.active) 	/* Use the previously allocated pointer */
+				Ctrl->Int16.data = (int16_t *)prhs->c_ptr.grd;
 			else
 				Ctrl->Int16.data = gmt_M_memory (GMT, NULL, n_alloc, int16_t);
 			break;
@@ -991,18 +1008,26 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 				Ctrl->Float.data = prhs->f_ptr.grd;
 				Ctrl->Float.active = true;		/* In case it was not set yet */
 			}
+			else if (prhs->c_ptr.active) {	/* Use the previously allocated pointer */
+				Ctrl->UInt16.data = (uint16_t *)prhs->c_ptr.grd;
+				Ctrl->UInt16.active = true;		/* In case it was not set yet */
+			}
 			else
 				Ctrl->UInt16.data = gmt_M_memory (GMT, NULL, n_alloc, uint16_t);
 			break;
 		case GDT_Int32:
 			if (prhs->f_ptr.active)		/* Use the previously allocated float pointer */
 				Ctrl->Float.data = prhs->f_ptr.grd;
+			else if (prhs->c_ptr.active) 	/* Use the previously allocated pointer */
+				Ctrl->Int32.data = (int32_t *)prhs->c_ptr.grd;
 			else
 				Ctrl->Int32.data = gmt_M_memory (GMT, NULL, n_alloc, int32_t);
 			break;
 		case GDT_UInt32:
 			if (prhs->f_ptr.active)		/* Use the previously allocated float pointer */
 				Ctrl->Float.data = prhs->f_ptr.grd;
+			else if (prhs->c_ptr.active) 	/* Use the previously allocated pointer */
+				Ctrl->UInt32.data = (uint32_t *)prhs->c_ptr.grd;
 			else
 				Ctrl->UInt32.data = gmt_M_memory (GMT, NULL, n_alloc, uint32_t);
 			break;
@@ -1018,7 +1043,7 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 			}
 			break;
 		default:
-			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "gdalread: Unsupported data type\n");
+			GMT_Report (GMT->parent, GMT_MSG_ERROR, "gdalread: Unsupported data type\n");
 			break;
 	}
 
@@ -1028,7 +1053,7 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 
 	if (!(just_copy || copy_flipud)) {
 		if ((tmp = calloc((size_t)nRowsPerBlock * (size_t)nBufXSize, nPixelSize)) == NULL) {
-			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "gdalread: failure to allocate enough memory\n");
+			GMT_Report (GMT->parent, GMT_MSG_ERROR, "gdalread: failure to allocate enough memory\n");
 			GDALDestroyDriverManager();
 			gmt_M_free (GMT, whichBands);
 			return(-1);
@@ -1051,6 +1076,8 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 	colVec = gmt_M_memory(GMT, NULL, nX+pad_w+pad_e, size_t);	/* For now this will be used only to select BIP ordering */
 	/* --------------------------------------------------------------------------------- */
 
+	gmt_M_tic (GMT);
+
 	for (i = 0; i < nBands; i++) {
 		if (!nReqBands)		/* No band selection, read them sequentialy */
 			hBand = GDALGetRasterBand(hDataset, i+1);
@@ -1066,7 +1093,10 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 			   (where all this (re)started) not only is bugged as it does not carry the AREA_OR_POINT metadata.
 			   So we'll check for the "Area" keyword and if found we will respect it and set grid to pix reg
 			*/
-			if (!pixel_reg && GDALGetMetadataItem(hDataset, "AREA_OR_POINT", NULL) &&
+			if (gmtlib_file_is_jpeg2000_tile (GMT->parent, gdal_filename) != GMT_NOTSET && (Ctrl->RasterXsize % 2) == 0 && (Ctrl->RasterYsize % 2) == 0)
+				/* PW: Reading GMT server special JP2 tiles: even size implies pixel registration */
+				pixel_reg = true;
+			else if (!pixel_reg && GDALGetMetadataItem(hDataset, "AREA_OR_POINT", NULL) &&
 				!strcmp(GDALGetMetadataItem(hDataset, "AREA_OR_POINT", NULL), "Area"))
 				pixel_reg = true;
 			else if (!pixel_reg && GDALGetMetadataItem(hDataset, "GDALMD_AREA_OR_POINT", NULL) &&
@@ -1093,178 +1123,195 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 			if (just_copy || copy_flipud)					/* In this case nBlocks was set to 1 above */
 				tmp = &Ctrl->UInt8.data[i_x_nXYSize];		/* These cases don't need any temporary array */
 
-		if ((gdal_code = GDALRasterIO(hBand, GF_Read, xOrigin, nYOff, nXSize, buffy, tmp,
+			if ((gdal_code = GDALRasterIO(hBand, GF_Read, xOrigin, nYOff, nXSize, buffy, tmp,
 		                 nBufXSize, buffy, GDALGetRasterDataType(hBand), 0, 0)) != CE_None) {
-			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "GDALRasterIO failed to open band %d [err = %d]\n", i, gdal_code);
-			continue;
-		}
-
-		/* If we didn't computed it yet, its time to do it now */
-		if (got_R) ComputeRasterMinMax(GMT, tmp, hBand, adfMinMax, nXSize, nYSize, z_min, z_max);
-
-		/* In the "Preview" mode those guys below are different and what we need is the BufSize */
-		if (jump) {
-			nXSize = nBufXSize;		nYSize = nBufYSize;
-		}
-
-		startColPos = pad_w + i_x_nXYSize + (complex_mode > 1);	/* Take into account nBands, Padding and Complex */
-		nXSize_withPad = nXSize + pad_w + pad_e;
-		nYSize_withPad = nYSize + pad_n + pad_s;
-
-		if (prhs->mini_hdr.active) {				/* Read into a padded zone that can be larger then grid dims (grdpaste) */
-			if (prhs->mini_hdr.side[0] == 'l' || prhs->mini_hdr.side[0] == 'r') {
-				nXSize_withPad = prhs->mini_hdr.mx;
-				if (prhs->mini_hdr.side[0] == 'r')
-					startColPos += prhs->mini_hdr.offset;
+				GMT_Report (GMT->parent, GMT_MSG_WARNING, "GDALRasterIO failed to open band %d [err = %d]\n", i, gdal_code);
+				continue;
 			}
-			else if (prhs->mini_hdr.side[0] == 'b') {
-				startRow = prhs->mini_hdr.offset + k * nRowsPerBlock;
-				endRow = startRow + nRowsPerBlock;
-				if (k == nBlocks-1)
-					endRow = prhs->mini_hdr.offset + nYSize;
+
+			/* If we didn't computed it yet, its time to do it now */
+			if (got_R) ComputeRasterMinMax(GMT, tmp, hBand, adfMinMax, nXSize, nYSize, z_min, z_max);
+
+			/* In the "Preview" mode those guys below are different and what we need is the BufSize */
+			if (jump) {
+				nXSize = nBufXSize;		nYSize = nBufYSize;
 			}
-		}
 
-		switch (GDALGetRasterDataType(hBand)) {
-			case GDT_Byte:
-				/* This chunk is kind of complicated because we want to take into account several different cases */
-				for (n = 0; n < nXSize; n++) {
-					if (do_BIP)			/* Vector for Pixel Interleaving */
-						colVec[n] = n * nRGBA + i;
-					else {				/* Vector for Band Sequential */
-						if (topdown)
-							colVec[n] = n * nY + i_x_nXYSize;
-						else
-							colVec[n] = n + i_x_nXYSize;
-					}
-				}
+			startColPos = pad_w + i_x_nXYSize + (complex_mode > 1);	/* Take into account nBands, Padding and Complex */
+			nXSize_withPad = nXSize + pad_w + pad_e;
+			nYSize_withPad = nYSize + pad_n + pad_s;
 
-				Ctrl->UInt8.active = true;
-				if (do_BIP || !GMT->current.gdal_read_in.O.mem_layout[0]) {
-					/* Currently all calls to send image to GMT (BIP case) must come through here */
-					if (rowmajor) {
-						for (m = row_i; m < row_e; m++) {
-							off = nRGBA * pad_w + (pad_w+m) * (nRGBA * (nXSize_withPad)); /* Remember, nRGBA is variable */
-							for (n = 0; n < nXSize; n++)
-								Ctrl->UInt8.data[colVec[n] + off] = tmp[rowVec[m]+n];
-						}
-					}
-					else {
-						for (n = 0; n < nXSize; n++) {
-							off = nRGBA * pad_n + (pad_n+n) * (nRGBA * nYSize_withPad) + i;
-							for (m = row_i; m < row_e; m++)
-								Ctrl->UInt8.data[m * nRGBA + off] = tmp[rowVec[m] + n];
-						}
-					}
+			if (prhs->mini_hdr.active) {		/* Read into a padded zone that can be larger then grid dims (grdpaste) */
+				if (prhs->mini_hdr.side[0] == 'l' || prhs->mini_hdr.side[0] == 'r') {
+					nXSize_withPad = prhs->mini_hdr.mx;
+					if (prhs->mini_hdr.side[0] == 'r')
+						startColPos += prhs->mini_hdr.offset;
 				}
-				else {
-					if (just_copy) {	/* Here we send out the array as is, but the usage of a tmp array was a waste. Needs fix */
-						memcpy (&Ctrl->UInt8.data[i_x_nXYSize], tmp, (size_t)nBufYSize * (size_t)nBufXSize);
-					}
-					else if (copy_flipud) {
-						/* We could copy and flip but the idea here is also to not use a tmp array too */
-						memcpy (&Ctrl->UInt8.data[i_x_nXYSize], tmp, (size_t)nBufYSize * (size_t)nBufXSize);
-						gmt_grd_flip_vertical (&Ctrl->UInt8.data[i_x_nXYSize], (unsigned)nX, (unsigned)nY, 0, 1);
-					}
-					else if (fliplr) {				/* No BIP option yet, and maybe never */
-						for (m = row_i; m < row_e; m++) {
-							nn = (pad_w+m)*(nXSize_withPad) + startColPos;
-							for (n = nXSize-1; n >= 0; n--)
-								Ctrl->UInt8.data[nn++] = tmp[rowVec[m]+n];
+				else if (prhs->mini_hdr.side[0] == 'b') {
+					startRow = prhs->mini_hdr.offset + k * nRowsPerBlock;
+					endRow = startRow + nRowsPerBlock;
+					if (k == nBlocks-1)
+						endRow = prhs->mini_hdr.offset + nYSize;
+				}
+			}
+
+			switch (GDALGetRasterDataType(hBand)) {
+				case GDT_Byte:
+					/* This chunk is kind of complicated because we want to take into account several different cases */
+					for (n = 0; n < nXSize; n++) {
+						if (do_BIP)			/* Vector for Pixel Interleaving */
+							colVec[n] = n * nRGBA + i;
+						else {				/* Vector for Band Sequential */
+							if (topdown)
+								colVec[n] = n * nY + i_x_nXYSize;
+							else
+								colVec[n] = n + i_x_nXYSize;
 						}
 					}
-					else if (topdown) {			/* No BIP option yet, and maybe never */
-						for (m = row_i; m < row_e; m++) {
+
+					Ctrl->UInt8.active = true;
+					if (do_BIP || !GMT->current.gdal_read_in.O.mem_layout[0]) {
+						/* Currently all calls to send image to GMT (BIP case) must come through here */
+						if (rowmajor) {
+							for (m = row_i; m < row_e; m++) {
+								off = nRGBA * pad_w + (pad_w+m) * (nRGBA * (nXSize_withPad)); /* Remember, nRGBA is variable */
+								for (n = 0; n < nXSize; n++)
+									Ctrl->UInt8.data[colVec[n] + off] = tmp[rowVec[m]+n];
+							}
+						}
+						else {
 							for (n = 0; n < nXSize; n++) {
-								ij = colVec[n] + m;
-								Ctrl->UInt8.data[ij] = tmp[rowVec[m]+n];
+								off = nRGBA * pad_n + (pad_n+n) * (nRGBA * nYSize_withPad) + i;
+								for (m = row_i; m < row_e; m++)
+									Ctrl->UInt8.data[m * nRGBA + off] = tmp[rowVec[m] + n];
 							}
 						}
 					}
-				}
-				break;
-			case GDT_Int16:
-				if (!prhs->f_ptr.active) Ctrl->Int16.active = true;
-				for (m = startRow, mm = 0; m < endRow; m++, mm++) {
-					nn = (pad_w+m)*(nXSize_withPad) + startColPos;
-					for (n = fliplr ? nXSize-1 : 0; fliplr ? n >= 0 : n < nXSize; fliplr ? n-- : n++)
-						if (prhs->f_ptr.active) {
-							int16_t tmpI16;
-							memcpy (&tmpI16, &tmp[(rowVec[mm] + n) * sizeof(int16_t)], sizeof(int16_t));
-							Ctrl->Float.data[nn++] = tmpI16;
+					else {
+						if (just_copy) {	/* Here we send out the array as is, but the usage of a tmp array was a waste. Needs fix */
+							memcpy (&Ctrl->UInt8.data[i_x_nXYSize], tmp, (size_t)nBufYSize * (size_t)nBufXSize);
 						}
-						else
-							memcpy(&Ctrl->Int16.data[nn++], &tmp[(rowVec[mm] + n) * sizeof(int16_t)], sizeof(int16_t));
-				}
-				break;
-			case GDT_UInt16:
-				if (!prhs->f_ptr.active) Ctrl->UInt16.active = true;
-				for (m = startRow, mm = 0; m < endRow; m++, mm++) {
-					nn = (pad_w+m)*(nXSize_withPad) + startColPos;
-					for (n = fliplr ? nXSize-1 : 0; fliplr ? n >= 0 : n < nXSize; fliplr ? n-- : n++)
-						if (prhs->f_ptr.active) {
-							uint16_t tmpUI16;
-							memcpy (&tmpUI16, &tmp[(rowVec[mm] + n) * sizeof(uint16_t)], sizeof(uint16_t));
-							Ctrl->Float.data[nn++] = tmpUI16;
+						else if (copy_flipud) {
+							/* We could copy and flip but the idea here is also to not use a tmp array too */
+							memcpy (&Ctrl->UInt8.data[i_x_nXYSize], tmp, (size_t)nBufYSize * (size_t)nBufXSize);
+							gmt_grd_flip_vertical (&Ctrl->UInt8.data[i_x_nXYSize], (unsigned)nX, (unsigned)nY, 0, 1);
 						}
-						else
-							memcpy (&Ctrl->UInt16.data[nn++], &tmp[(rowVec[mm] + n) * sizeof(uint16_t)], sizeof(uint16_t));
-				}
-				break;
-			case GDT_Int32:
-				if (!prhs->f_ptr.active) Ctrl->Int32.active = true;
-				for (m = startRow, mm = 0; m < endRow; m++, mm++) {
-					nn = (pad_w+m)*(nXSize_withPad) + startColPos;
-					for (n = fliplr ? nXSize-1 : 0; fliplr ? n >= 0 : n < nXSize; fliplr ? n-- : n++)
-						if (prhs->f_ptr.active) {
-							int32_t tmpI32;
-							memcpy (&tmpI32, &tmp[(rowVec[mm] + n) * sizeof(int32_t)], sizeof(int32_t));
-							Ctrl->Float.data[nn++] = (float)tmpI32;
+						else if (fliplr) {				/* No BIP option yet, and maybe never */
+							for (m = row_i; m < row_e; m++) {
+								nn = (pad_w+m)*(nXSize_withPad) + startColPos;
+								for (n = nXSize-1; n >= 0; n--)
+									Ctrl->UInt8.data[nn++] = tmp[rowVec[m]+n];
+							}
 						}
-						else
-							memcpy (&Ctrl->Int32.data[nn++], &tmp[(rowVec[mm] + n) * sizeof(int32_t)], sizeof(int32_t));
-				}
-				break;
-			case GDT_UInt32:
-				if (!prhs->f_ptr.active) Ctrl->UInt32.active = true;
-				for (m = startRow, mm = 0; m < endRow; m++, mm++) {
-					nn = (pad_w+m)*(nXSize_withPad) + startColPos;
-					for (n = fliplr ? nXSize-1 : 0; fliplr ? n >= 0 : n < nXSize; fliplr ? n-- : n++)
-						if (prhs->f_ptr.active) {
-							int32_t tmpUI32;
-							memcpy (&tmpUI32, &tmp[(rowVec[mm] + n) * sizeof(int32_t)], sizeof(int32_t));
-							Ctrl->Float.data[nn++] = (float)tmpUI32;
+						else if (topdown) {			/* No BIP option yet, and maybe never */
+							for (m = row_i; m < row_e; m++) {
+								for (n = 0; n < nXSize; n++) {
+									ij = colVec[n] + m;
+									Ctrl->UInt8.data[ij] = tmp[rowVec[m]+n];
+								}
+							}
 						}
-						else
-							memcpy (&Ctrl->UInt32.data[nn++], &tmp[(rowVec[mm] + n) * sizeof(int32_t)], sizeof(int32_t));
-				}
-				break;
-			case GDT_Float32:
-				Ctrl->Float.active = true;
-				for (m = startRow, mm = 0; m < endRow; m++, mm++) {
-					nn = (pad_w+m)*(nXSize_withPad) + startColPos;
-					for (n = 0; n < nXSize; n++) {
-						memcpy (&Ctrl->Float.data[nn], &tmp[(rowVec[mm]+n) * sizeof(float)], sizeof(float));
-						nn += incStep;
 					}
-				}
-				break;
-			case GDT_Float64:	/* For now we don't care about doubles */
-				Ctrl->Float.active = true;
-				for (m = startRow, mm = 0; m < endRow; m++, mm++) {
-					nn = (pad_w+m)*(nXSize_withPad) + startColPos;
-					for (n = 0; n < nXSize; n++) {
-						double tmpF64;
-						memcpy (&tmpF64, &tmp[(rowVec[mm]+n) * sizeof(double)], sizeof(double));
-						Ctrl->Float.data[nn] = (float)tmpF64;
-						nn += incStep;
+					break;
+				case GDT_Int16:
+					if (!prhs->f_ptr.active) Ctrl->Int16.active = true;
+					if (gmtlib_file_is_jpeg2000_tile (GMT->parent, gdal_filename) != GMT_NOTSET) {
+						/* PW: Special case of jp2 tile with possible NaNs that are not recognized without the .aux.xml file */
+						float f_NaN = GMT->session.f_NaN;	/* Shorthand */
+						for (m = startRow, mm = 0; m < endRow; m++, mm++) {
+							nn = (pad_w+m)*(nXSize_withPad) + startColPos;
+							for (n = fliplr ? nXSize-1 : 0; fliplr ? n >= 0 : n < nXSize; fliplr ? n-- : n++)
+								if (prhs->f_ptr.active) {
+									int16_t tmpI16;
+									memcpy (&tmpI16, &tmp[(rowVec[mm] + n) * sizeof(int16_t)], sizeof(int16_t));
+									Ctrl->Float.data[nn++] = (tmpI16 == -32768) ? f_NaN : tmpI16;
+								}
+								else
+									memcpy(&Ctrl->Int16.data[nn++], &tmp[(rowVec[mm] + n) * sizeof(int16_t)], sizeof(int16_t));
+						}
 					}
-				}
-				break;
-			default:
-				CPLAssert(false);
+					else {	/* All other short int cases */
+						for (m = startRow, mm = 0; m < endRow; m++, mm++) {
+							nn = (pad_w+m)*(nXSize_withPad) + startColPos;
+							for (n = fliplr ? nXSize-1 : 0; fliplr ? n >= 0 : n < nXSize; fliplr ? n-- : n++)
+								if (prhs->f_ptr.active) {
+									int16_t tmpI16;
+									memcpy (&tmpI16, &tmp[(rowVec[mm] + n) * sizeof(int16_t)], sizeof(int16_t));
+									Ctrl->Float.data[nn++] = tmpI16;
+								}
+								else
+									memcpy(&Ctrl->Int16.data[nn++], &tmp[(rowVec[mm] + n) * sizeof(int16_t)], sizeof(int16_t));
+						}
+					}
+					break;
+				case GDT_UInt16:
+					if (!prhs->f_ptr.active) Ctrl->UInt16.active = true;
+					for (m = startRow, mm = 0; m < endRow; m++, mm++) {
+						nn = (pad_w+m)*(nXSize_withPad) + startColPos;
+						for (n = fliplr ? nXSize-1 : 0; fliplr ? n >= 0 : n < nXSize; fliplr ? n-- : n++)
+							if (prhs->f_ptr.active) {
+								uint16_t tmpUI16;
+								memcpy (&tmpUI16, &tmp[(rowVec[mm] + n) * sizeof(uint16_t)], sizeof(uint16_t));
+								Ctrl->Float.data[nn++] = tmpUI16;
+							}
+							else
+								memcpy (&Ctrl->UInt16.data[nn++], &tmp[(rowVec[mm] + n) * sizeof(uint16_t)], sizeof(uint16_t));
+					}
+					break;
+				case GDT_Int32:
+					if (!prhs->f_ptr.active) Ctrl->Int32.active = true;
+					for (m = startRow, mm = 0; m < endRow; m++, mm++) {
+						nn = (pad_w+m)*(nXSize_withPad) + startColPos;
+						for (n = fliplr ? nXSize-1 : 0; fliplr ? n >= 0 : n < nXSize; fliplr ? n-- : n++)
+							if (prhs->f_ptr.active) {
+								int32_t tmpI32;
+								memcpy (&tmpI32, &tmp[(rowVec[mm] + n) * sizeof(int32_t)], sizeof(int32_t));
+								Ctrl->Float.data[nn++] = (float)tmpI32;
+							}
+							else
+								memcpy (&Ctrl->Int32.data[nn++], &tmp[(rowVec[mm] + n) * sizeof(int32_t)], sizeof(int32_t));
+					}
+					break;
+				case GDT_UInt32:
+					if (!prhs->f_ptr.active) Ctrl->UInt32.active = true;
+					for (m = startRow, mm = 0; m < endRow; m++, mm++) {
+						nn = (pad_w+m)*(nXSize_withPad) + startColPos;
+						for (n = fliplr ? nXSize-1 : 0; fliplr ? n >= 0 : n < nXSize; fliplr ? n-- : n++)
+							if (prhs->f_ptr.active) {
+								int32_t tmpUI32;
+								memcpy (&tmpUI32, &tmp[(rowVec[mm] + n) * sizeof(int32_t)], sizeof(int32_t));
+								Ctrl->Float.data[nn++] = (float)tmpUI32;
+							}
+							else
+								memcpy (&Ctrl->UInt32.data[nn++], &tmp[(rowVec[mm] + n) * sizeof(int32_t)], sizeof(int32_t));
+					}
+					break;
+				case GDT_Float32:
+					Ctrl->Float.active = true;
+					for (m = startRow, mm = 0; m < endRow; m++, mm++) {
+						nn = (pad_w+m)*(nXSize_withPad) + startColPos;
+						for (n = 0; n < nXSize; n++) {
+							memcpy (&Ctrl->Float.data[nn], &tmp[(rowVec[mm]+n) * sizeof(float)], sizeof(float));
+							nn += incStep;
+						}
+					}
+					break;
+				case GDT_Float64:	/* For now we don't care about doubles */
+					Ctrl->Float.active = true;
+					for (m = startRow, mm = 0; m < endRow; m++, mm++) {
+						nn = (pad_w+m)*(nXSize_withPad) + startColPos;
+						for (n = 0; n < nXSize; n++) {
+							double tmpF64;
+							memcpy (&tmpF64, &tmp[(rowVec[mm]+n) * sizeof(double)], sizeof(double));
+							Ctrl->Float.data[nn] = (float)tmpF64;
+							nn += incStep;
+						}
+					}
+					break;
+				default:
+					CPLAssert(false);
+			}
 		}
-}
 	}
 
 #if 0	/* This code is problematic and commented out for now. PW, 5/15/2016 */
@@ -1286,6 +1333,8 @@ int gmt_gdalread (struct GMT_CTRL *GMT, char *gdal_filename, struct GMT_GDALREAD
 
 	GDALClose(hDataset);
 
+	gmt_M_toc (GMT, "After gdalread data reading");
+
 	populate_metadata (GMT, Ctrl, gdal_filename, got_R, nXSize, nYSize, dfULX, dfULY, dfLRX, dfLRY, z_min, z_max, first_layer);
 
 	GDALDestroyDriverManager();
