@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *	Copyright (c) 1991-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -43,13 +43,16 @@ struct GMT_MATH_MACRO {
 	char **arg;	/* List of those commands */
 };
 
-#ifdef USE_GMT_KWD
-/*! Definition of GMT_KW_DICT used to expand keyword-value pairs to GMT options */
-struct GMT_KW_DICT {	/* Used for keyword-value lookup */
-	char code;	/* Single character GMT option code */
-	char name[31];	/* Name of corresponding keyword */
+/*! Definition of GMT_KEYWORD_DICTIONARY used to expand keyword-value pairs to GMT options */
+struct GMT_KEYWORD_DICTIONARY {	/* Used for keyword-value lookup */
+	char separator;			/* Single character separating 2 or more identical specifications [0 for no repeat] */
+	char short_option;		/* Single character GMT option code */
+	char long_option[31];		/* Name of corresponding long option */
+	char short_directives[32];	/* Single character directives, comma-separated */
+	char long_directives[256];	/* Long name directives, comma-separated */
+	char short_modifiers[32];	/* Single character modifiers, comma-separated */
+	char long_modifiers[256];	/* Long name modifiers, comma-separated */
 };
-#endif
 
 /*! Definition of structure use for finding optimal n_columns/n_rows for surface */
 struct GMT_SURFACE_SUGGESTION {	/* Used to find top ten list of faster grid dimensions  */
@@ -93,8 +96,8 @@ struct GMT_RANGE {
 /*! For information on 1-D array */
 
 struct GMT_ARRAY {	/* Used by modules that needs to set up 1-D output/bin arrays */
-	bool temporal;	/* true if array will be in absolute time */ 
-	bool vartime;	/* true if <unit> implies a variable calendar unit */ 
+	bool temporal;	/* true if array will be in absolute time */
+	bool vartime;	/* true if <unit> implies a variable calendar unit */
 	bool count;	/* true if we got number of items rather than increment */
 	bool add;	/* true if we are asked to add a computed spatial distance column to output */
 	bool reverse;	/* true if we want to reverse the array to give high to low on output */
@@ -103,7 +106,7 @@ struct GMT_ARRAY {	/* Used by modules that needs to set up 1-D output/bin arrays
 	bool logarithmic;	/* true if inc = 1,2,3 and we want logarithmic scale */
 	bool logarithmic2;	/* true if inc = integer and we want log2 scale */
 	bool delay[2];	/* true if min and/or max shall be set from data set extremes after read [false] */
-	unsigned int spatial;	/* 1 if <unit> implies a Cartesian and 2 if a geospatial distance */ 
+	unsigned int spatial;	/* 1 if <unit> implies a Cartesian and 2 if a geospatial distance */
 	unsigned int set;	/* 1 if inc set, 3 if min/max/in set, 0 otherwise */
 	unsigned int col;	/* The column that this array goes with */
 	int distmode;	/* Type of geospatial calculation mode for distances */
@@ -139,7 +142,7 @@ struct GMT_INSET {
 struct GMT_SUBPLOT {
 	unsigned int active;	/* 1 if subplot is in effect */
 	unsigned int first;		/* 1 the first time we reach panel, 0 later */
-	unsigned int no_scaling;	/* 1 when we are plotting a scale, bar, etc and not map and dont want to auto-scale plot */
+	unsigned int no_scaling;	/* 1 when we are plotting a scale, bar, etc and not map and don't want to auto-scale plot */
 	unsigned int parallel;	/* 1 for axis-parallel annotations [0 for standard] */
 	int row, col;			/* Current panel position e.g., 0,0 */
 	int nrows, ncolumns;	/* Panel arrangement for subplot window */
@@ -274,8 +277,8 @@ struct GMT_Y2K_FIX {	/* The issue that refuses to go away... */
 };
 
 struct GMT_MOMENT_INTERVAL {
-	struct GMT_GCAL	cc[2];		
-	double dt[2];		
+	struct GMT_GCAL	cc[2];
+	double dt[2];
 	double sd[2];		/* Seconds since the start of the day.  */
 	int64_t rd[2];
 	unsigned int step;
@@ -311,7 +314,6 @@ struct GMT_INIT { /* Holds misc run-time parameters */
 	char *runtime_library;        /* Name of the main shared library at run-time */
 	char *runtime_plugindir;      /* Directory that contains the main supplemental plugins at run-time */
 	char *history[GMT_N_UNIQUE];  /* The internal gmt.history information */
-	char cpt[GMT_N_CPT][GMT_LEN16];	/* The default CPTs for different data types; see gmt_cpt_default() */
 	struct GMT_CUSTOM_SYMBOL **custom_symbol; /* For custom symbol plotting in psxy[z]. */
 };
 
@@ -326,6 +328,7 @@ struct GMT_PLOT {		/* Holds all plotting-related parameters */
 	/* The rest of the struct contains pointers that may point to memory not included by this struct */
 	double *x;			/* Holds the x/y (inches) of a line to be plotted */
 	double *y;
+	double gridline_spacing[2];		/* Holds last gridline spacing used for this plot, via gmt.history */
 	char format[3][2][GMT_LEN256];	/* Keeps the 6 formats for dd:mm:ss plot output */
 	struct GMT_SUBPLOT panel;	/* Current subplot panel settings */
 	struct GMT_INSET inset;		/* Current inset settings */
@@ -345,9 +348,9 @@ struct GMT_CURRENT {
 	struct GMT_OPTION *options;	/* Pointer to current program's options */
 	struct GMT_FFT_HIDDEN fft;	/* Structure with info that must survive between FFT calls */
 #ifdef HAVE_GDAL
-	struct GMT_GDALREAD_IN_CTRL  gdal_read_in;  /* Hold parameters related to options transmitted to gdalread */ 
-	struct GMT_GDALREAD_OUT_CTRL gdal_read_out; /* Hold parameters related to options transmitted from gdalread */ 
-	struct GMT_GDALWRITE_CTRL    gdal_write;    /* Hold parameters related to options transmitted to gdalwrite */ 
+	struct GMT_GDALREAD_IN_CTRL  gdal_read_in;  /* Hold parameters related to options transmitted to gdalread */
+	struct GMT_GDALREAD_OUT_CTRL gdal_read_out; /* Hold parameters related to options transmitted from gdalread */
+	struct GMT_GDALWRITE_CTRL    gdal_write;    /* Hold parameters related to options transmitted to gdalwrite */
 #endif
 };
 
@@ -393,7 +396,7 @@ struct GMT_SESSION {
 	char unit_name[4][GMT_LEN8];	/* Full name of the 4 units cm, inch, m, pt */
 	struct GMT_HASH rgb_hashnode[GMT_N_COLOR_NAMES];/* Used to translate colornames to r/g/b */
 	bool rgb_hashnode_init;		/* true once the rgb_hashnode array has been loaded; false otherwise */
-	unsigned int n_shorthands;			/* Length of arrray with shorthand information */
+	unsigned int n_shorthands;			/* Length of array with shorthand information */
 	char *grdformat[GMT_N_GRD_FORMATS];	/* Type and description of grid format */
 	int (*readinfo[GMT_N_GRD_FORMATS]) (struct GMT_CTRL *, struct GMT_GRID_HEADER *);	/* Pointers to grid read header functions */
 	int (*updateinfo[GMT_N_GRD_FORMATS]) (struct GMT_CTRL *, struct GMT_GRID_HEADER *);	/* Pointers to grid update header functions */
@@ -442,7 +445,7 @@ typedef int (*p_to_io_func) (struct GMT_CTRL *, FILE *, uint64_t, double *);
    let GMT_exit possibly call exit, else it does nothing.  Thus, calls to GMT_exit
    must be followed by return <type> so that we return where we said we would. */
 
-/* If GMT is not set or no_not_exit is false then we call system exit, else we move along */
+/* If GMT is not set or do_not_exit is false then we call system exit, else we move along */
 static inline void GMT_exit (struct GMT_CTRL *GMT, int code) {
 	if (GMT == NULL || GMT->parent == NULL || GMT->parent->do_not_exit == false)
 		exit (code);
